4Suite API Documentation: Ft

4Suite™ API Documentation

# ► Module Ft

4Suite: an open-source platform for XML and RDF processing.

    Copyright 2004 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: FtException, FtWarning |  |  |  | Functions: GetConfigVar, GetConfigVars, TranslateMessage |  |  |  | Globals: DEFAULT_ENCODING, MAX_PYTHON_RECURSION_DEPTH, __version__

## Modules

Lib | Module providing common utilities for many 4Suite components, as well as for general use.
Xml | Module providing utilities for processing XML files

## Classes

class FtException(Exception)
  Base class for all 4Suite-specific exceptions

  ### Methods

  __getattr__(self, name)
  __init__(self, errorCode, messages, argtuple=(), **kwargs)
    errorCode = Numeric ID for the type of error. messages = Mapping of errorCodes to localized error message strings. argtuple or keyword args = Values for message string formatting.
    Overrides: __init__ from class Exception
  __repr__(self)
  __str__(self)
    Overrides: __str__ from class Exception

  ### Methods inherited from class Exception

  __getitem__
class FtWarning(Warning)
  Base class for all 4Suite-specific warnings.

  ### Methods inherited from class Exception

  __getitem__, __init__, __str__

## Functions

GetConfigVar(name)
  Return the value of a single variable using the dictionary returned by 'get_config_vars()'. Equivalent to GetConfigVars().get(name)
GetConfigVars(*names)
  With no arguments, return a dictionary of all configuration variables relevant for the current installation. With arguments, return a list of values that result from looking up each argument in the configuration variable dictionary.

      The following are the currently defined variables and their meaning:

      NAME, FULLNAME, VERSION, URL - fields as given for call to setup()
      BINDIR - directory for user executables
      DATADIR - directory for read-only platform-independent data
      LIBDIR - directory for extra libraries
      LOCALEDIR - directory for message catalogs
      LOCALSTATEDIR - directory for modifiable host-specific data
      SYSCONFIDIR - directory for read-only host-specific data

TranslateMessage = gettext(...)

## Globals

DEFAULT_ENCODING = 'UTF-8'
MAX_PYTHON_RECURSION_DEPTH = 10000
__version__ = '0.0'